@@ -17,5 +17,3 @@ __version__ = meta.get_version()
 __author__ = u"Paul Müller"
 __license__ = "GPL v2"
 
-# Import the GUI in the end, because it needs `__version__`.
-from .gui.main import Main
\ No newline at end of file
